@@ -15,34 +15,35 @@
 # Importing non-modules that are not used explicitly
 
 # FIXME(gabriel): Legacy imports for API compatibility.
-from django.core.exceptions import ValidationError  # noqa
-from django.forms.fields import *  # noqa
-from django.forms.forms import *  # noqa
+from django.core.exceptions import ValidationError
+from django.forms.fields import *  # noqa: F403,H303
+from django.forms.forms import *  # noqa: F403,H303
 from django.forms import widgets
-from django.forms.widgets import *  # noqa
+from django.forms.widgets import *  # noqa: F403,H303
 
 
 # Convenience imports for public API components.
-from horizon.forms.base import DateForm  # noqa
-from horizon.forms.base import SelfHandlingForm  # noqa
-from horizon.forms.base import SelfHandlingMixin  # noqa
-from horizon.forms.fields import DynamicChoiceField  # noqa
-from horizon.forms.fields import DynamicTypedChoiceField  # noqa
-from horizon.forms.fields import ExternalFileField  # noqa
-from horizon.forms.fields import ExternalUploadMeta  # noqa
-from horizon.forms.fields import IPField  # noqa
-from horizon.forms.fields import IPv4  # noqa
-from horizon.forms.fields import IPv6  # noqa
-from horizon.forms.fields import MultiIPField  # noqa
-from horizon.forms.fields import SelectWidget  # noqa
-from horizon.forms.fields import ThemableCheckboxInput  # noqa
-from horizon.forms.fields import ThemableCheckboxSelectMultiple  # noqa
-from horizon.forms.fields import ThemableChoiceField  # noqa
-from horizon.forms.fields import ThemableDynamicChoiceField  # noqa
-from horizon.forms.fields import ThemableDynamicTypedChoiceField  # noqa
-from horizon.forms.fields import ThemableSelectWidget  # noqa
-from horizon.forms.views import ModalFormMixin  # noqa
-from horizon.forms.views import ModalFormView  # noqa
+from horizon.forms.base import DateForm
+from horizon.forms.base import SelfHandlingForm
+from horizon.forms.base import SelfHandlingMixin
+from horizon.forms.fields import DynamicChoiceField
+from horizon.forms.fields import DynamicTypedChoiceField
+from horizon.forms.fields import ExternalFileField
+from horizon.forms.fields import ExternalUploadMeta
+from horizon.forms.fields import IPField
+from horizon.forms.fields import IPv4
+from horizon.forms.fields import IPv6
+from horizon.forms.fields import MACAddressField
+from horizon.forms.fields import MultiIPField
+from horizon.forms.fields import SelectWidget
+from horizon.forms.fields import ThemableCheckboxInput
+from horizon.forms.fields import ThemableCheckboxSelectMultiple
+from horizon.forms.fields import ThemableChoiceField
+from horizon.forms.fields import ThemableDynamicChoiceField
+from horizon.forms.fields import ThemableDynamicTypedChoiceField
+from horizon.forms.fields import ThemableSelectWidget
+from horizon.forms.views import ModalFormMixin
+from horizon.forms.views import ModalFormView
 
 
 __all__ = [
@@ -53,14 +54,18 @@ __all__ = [
     "ModalFormMixin",
     "DynamicTypedChoiceField",
     "DynamicChoiceField",
+    "ExternalFileField",
+    "ExternalUploadMeta",
     "ThemableCheckboxInput",
     "ThemableCheckboxSelectMultiple",
     "ThemableChoiceField",
     "ThemableDynamicChoiceField",
+    "ThemableDynamicTypedChoiceField",
     "ThemableSelectWidget",
     "IPField",
     "IPv4",
     "IPv6",
+    "MACAddressField",
     "MultiIPField",
     "SelectWidget",
 
