@@ -18,34 +18,33 @@
 
 from django.conf import settings
 from django.conf.urls import include
-from django.conf.urls import patterns
 from django.conf.urls import url
-from django.views.generic import TemplateView  # noqa
+from django.views.generic import TemplateView
+from django.views import i18n
 
 from horizon.test.jasmine import jasmine
+from horizon import views
 
-urlpatterns = patterns(
-    'horizon.views',
-    url(r'^home/$', 'user_home', name='user_home')
-)
+urlpatterns = [
+    url(r'^home/$', views.user_home, name='user_home')
+]
 
 # Client-side i18n URLconf.
-urlpatterns += patterns(
-    '',
+urlpatterns.extend([
     url(r'^i18n/js/(?P<packages>\S+?)/$',
-        'django.views.i18n.javascript_catalog',
+        i18n.javascript_catalog,
         name='jsi18n'),
     url(r'^i18n/setlang/$',
-        'django.views.i18n.set_language',
+        i18n.set_language,
         name="set_language"),
     url(r'^i18n/', include('django.conf.urls.i18n'))
-)
+])
 
 if settings.DEBUG:
-    urlpatterns += patterns(
-        '',
+    urlpatterns.extend([
         url(r'^jasmine-legacy/$',
             TemplateView.as_view(
                 template_name="horizon/jasmine/jasmine_legacy.html"),
             name='jasmine_tests'),
-        url(r'^jasmine/.*?$', jasmine.dispatcher))
+        url(r'^jasmine/.*?$', jasmine.dispatcher),
+    ])
