@@ -19,6 +19,8 @@
   angular
     .module('horizon.framework.util.filters')
     .filter('yesno', yesNoFilter)
+    .filter('simpleDate', simpleDateFilter)
+    .filter('mediumDate', mediumDateFilter)
     .filter('gb', gbFilter)
     .filter('mb', mbFilter)
     .filter('title', titleFilter)
@@ -45,6 +47,32 @@
     };
   }
 
+  /**
+   * @ngdoc filter
+   * @name simpleDate
+   * @description
+   * Evaluates given for display as a short date, returning '-' if empty.
+   */
+  simpleDateFilter.$inject = ['$filter'];
+  function simpleDateFilter($filter) {
+    return function (input) {
+      return $filter('noValue')($filter('date')(input, 'short'));
+    };
+  }
+
+  /**
+   * @ngdoc filter
+   * @name mediumDate
+   * @description
+   * Evaluates given for display as a medium date, returning '-' if empty.
+   */
+  mediumDateFilter.$inject = ['$filter'];
+  function mediumDateFilter($filter) {
+    return function (input) {
+      return $filter('noValue')($filter('date')(input, 'medium'));
+    };
+  }
+
   /**
    * @ngdoc filter
    * @name gb
@@ -133,7 +161,7 @@
   function noValueFilter() {
     return function (input, def) {
       if (input === null || angular.isUndefined(input) ||
-        (angular.isString(input) && '' === input.trim())) {
+        angular.isString(input) && '' === input.trim()) {
         return def || gettext('-');
       } else {
         return input;
@@ -208,9 +236,9 @@
   function itemCountFilter() {
 
     function ensureNonNegative(input) {
-      var isNumeric = (input !== null && isFinite(input));
+      var isNumeric = input !== null && isFinite(input);
       var number = isNumeric ? Math.round(input) : 0;
-      return (number > 0) ? number : 0;
+      return number > 0 ? number : 0;
     }
 
     return function (input, totalInput) {
