@@ -1,3 +1,17 @@
+/**
+ * Licensed under the Apache License, Version 2.0 (the "License"); you may
+ * not use this file except in compliance with the License. You may obtain
+ * a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+ * License for the specific language governing permissions and limitations
+ * under the License.
+ */
+
 (function () {
   'use strict';
 
@@ -38,6 +52,36 @@
       });
     });
 
+    describe('simpleDate', function () {
+      var simpleDateFilter;
+      beforeEach(inject(function (_simpleDateFilter_) {
+        simpleDateFilter = _simpleDateFilter_;
+      }));
+
+      it('returns blank if nothing', function () {
+        expect(simpleDateFilter()).toBe('-');
+      });
+
+      it('returns the expected time', function() {
+        expect(simpleDateFilter('2016-06-24T04:19:07')).toBe('6/24/16 4:19 AM');
+      });
+    });
+
+    describe('mediumDate', function () {
+      var mediumDateFilter;
+      beforeEach(inject(function (_mediumDateFilter_) {
+        mediumDateFilter = _mediumDateFilter_;
+      }));
+
+      it('returns blank if nothing', function () {
+        expect(mediumDateFilter()).toBe('-');
+      });
+
+      it('returns the expected time', function() {
+        expect(mediumDateFilter('2001-02-03T16:05:06')).toBe('Feb 3, 2001 4:05:06 PM');
+      });
+    });
+
     describe('gb', function () {
       var gbFilter;
       beforeEach(inject(function (_gbFilter_) {
