@@ -27,7 +27,8 @@
     '$scope',
     '$q',
     'horizon.framework.widgets.wizard.labels',
-    'horizon.framework.widgets.wizard.events'
+    'horizon.framework.widgets.wizard.events',
+    'horizon.framework.events'
   ];
 
   /**
@@ -36,7 +37,8 @@
     * @description
     * Controller used by 'wizard'
     */
-  function WizardController($scope, $q, wizardLabels, wizardEvents) {
+  function WizardController($scope, $q, wizardLabels, wizardEvents, frameworkEvents) {
+    var ctrl = this;
     var viewModel = $scope.viewModel = {};
     var initTask = $q.defer();
 
@@ -55,6 +57,10 @@
 
     $scope.switchTo = switchTo;
     $scope.showError = showError;
+    ctrl.toggleHelpBtn = toggleHelpBtn;
+    ctrl.onInitSuccess = onInitSuccess;
+    ctrl.onInitError = onInitError;
+
     /*eslint-enable angular/controller-as */
 
     viewModel.btnText = extend({}, wizardLabels, $scope.workflow.btnText);
@@ -85,7 +91,7 @@
         from: $scope.currentIndex,
         to: index
       });
-      toggleHelpBtn(index);
+      ctrl.toggleHelpBtn(index);
       /*eslint-disable angular/controller-as */
       $scope.currentIndex = index;
       $scope.openHelp = false;
@@ -122,9 +128,13 @@
     }
 
     function onInitSuccess() {
+      if (viewModel.hasError) {
+        return;
+      }
+
       $scope.$broadcast(wizardEvents.ON_INIT_SUCCESS);
       if (steps.length > 0) {
-        toggleHelpBtn(0);
+        ctrl.toggleHelpBtn(0);
       }
     }
 
@@ -132,6 +142,12 @@
       $scope.$broadcast(wizardEvents.ON_INIT_ERROR);
     }
 
+    $scope.$on(frameworkEvents.FORCE_LOGOUT, function(evt, arg) {
+      viewModel.hasError = true;
+      viewModel.errorMessage = arg;
+      return;
+    });
+
     function toggleHelpBtn(index) {
       // Toggle help icon button if a step's helpUrl is not defined
       if (angular.isUndefined(steps[index].helpUrl)) {
