@@ -1,3 +1,17 @@
+/**
+ * Licensed under the Apache License, Version 2.0 (the "License"); you may
+ * not use this file except in compliance with the License. You may obtain
+ * a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+ * License for the specific language governing permissions and limitations
+ * under the License.
+ */
+
 /* Namespace for core functionality related to Membership Workflow Step. */
 horizon.membership = {
 
@@ -7,14 +21,25 @@ horizon.membership = {
   has_roles: [],
   default_role_id: [],
 
-  /* Parses the form field selector's ID to get either the
-   * role or user id (i.e. returns "id12345" when
-   * passed the selector with id: "id_group_id12345").
+  /* Parses the form field selector's ID to get the
+   * role id. It returns the string after the last underscore.
+   * (i.e. returns "id12345" when passed the selector with
+   * id: "id_group_id12345").
    **/
   get_field_id: function(id_string) {
     return id_string.slice(id_string.lastIndexOf("_") + 1);
   },
 
+  /*
+   * Parses the form field selector's ID to get the member
+   * user id, which is usually right after the step slug.
+   * (i.e. returns "aa_bb" when passed the selector with
+   * id: "id_update_members_aa_bb").
+   **/
+  get_member_id: function(id_string, step_slug) {
+    return id_string.slice(id_string.indexOf(step_slug) + step_slug.length + 1);
+  },
+
   /*
    * Gets the html select element associated with a given
    * role id.
@@ -248,7 +273,7 @@ horizon.membership = {
     $(".available_" + step_slug + ", ." + step_slug + "_members").on('click', ".btn-group a[href='#add_remove']", function (evt) {
       evt.preventDefault();
       var available = $(".available_" + step_slug).has($(this)).length;
-      var data_id = horizon.membership.get_field_id($(this).parent().siblings().attr('data-' + step_slug + '-id'));
+      var data_id = horizon.membership.get_member_id($(this).parent().siblings().attr('data-' + step_slug + '-id'), step_slug);
       var member_el = $(this).parent().parent();
 
       if (available) {
@@ -272,9 +297,7 @@ horizon.membership = {
       // update lists
       horizon.membership.list_filtering(step_slug);
       horizon.membership.detect_no_results(step_slug);
-
-      // remove input filters
-      $("input." + step_slug + "_filter").val("");
+      $("input." + step_slug + "_filter").trigger("keyup");
     });
   },
 
@@ -283,7 +306,7 @@ horizon.membership = {
    * displays a message to the user.
    **/
   detect_no_results: function (step_slug) {
-    $('.' + step_slug + '_filterable').each( function () {
+    $('.' + step_slug + '_filterable').each(function () {
       var css_class = $(this).find('ul').attr('class');
       // Example value: members step_slug_members
       // Pick the class name that contains the step_slug
@@ -311,7 +334,7 @@ horizon.membership = {
       // get the newly selected role and the member's name
       var new_role_id = $(this).attr("data-role-id");
       var id_str = $(this).parent().parent().siblings(".member").attr("data-" + step_slug + "-id");
-      var data_id = horizon.membership.get_field_id(id_str);
+      var data_id = horizon.membership.get_member_id(id_str, step_slug);
       // update role lists
       if ($(this).hasClass('selected')) {
         $(this).removeClass('selected');
@@ -369,7 +392,7 @@ horizon.membership = {
    * Fixes the striping of the fake table upon modification of the lists.
    **/
   fix_stripes: function(step_slug) {
-    $('.fake_' + step_slug + '_table').each( function () {
+    $('.fake_' + step_slug + '_table').each(function () {
       var filter = "." + $(this).attr('id');
       var visible = " .btn-group:visible";
       var even = " .btn-group:visible:even";
@@ -437,7 +460,7 @@ horizon.membership = {
    * Calls set-up functions upon loading the workflow.
    **/
   workflow_init: function(modal, step_slug, step_id) {
-      $(modal).find('form').each( function () {
+      $(modal).find('form').each(function () {
       var $form = $(this);
 
       // Do nothing if this isn't a membership modal
@@ -480,7 +503,7 @@ horizon.membership = {
       horizon.membership.detect_no_results(step_slug);
 
       // fix initial striping of rows
-      $form.find('.fake_' + step_slug + '_table').each( function () {
+      $form.find('.fake_' + step_slug + '_table').each(function () {
         var filter = "." + $(this).attr('id');
         $(filter + ' .btn-group:even').addClass('dark_stripe');
         $(filter + ' .btn-group:last').addClass('last_stripe');
