@@ -1,3 +1,17 @@
+/**
+ * Licensed under the Apache License, Version 2.0 (the "License"); you may
+ * not use this file except in compliance with the License. You may obtain
+ * a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+ * License for the specific language governing permissions and limitations
+ * under the License.
+ */
+
 //TODO(lcastell):Inline edit is deprecated and will be removed in Horizon 12.0
 horizon.inline_edit = {
   get_cell_id: function (td_element) {
@@ -84,13 +98,13 @@ horizon.inline_edit = {
             if (redir_url){
               location.href = redir_url;
             } else {
-              horizon.alert("error", gettext("Not authorized to do this operation."));
+              horizon.toast.add("error", gettext("Not authorized to do this operation."));
             }
           }
           else {
             if (!horizon.ajax.get_messages(jqXHR)) {
               // Generic error handler. Really generic.
-              horizon.alert("error", gettext("An error occurred. Please try again later."));
+              horizon.toast.add("error", gettext("An error occurred. Please try again later."));
             }
           }
         },
@@ -159,13 +173,13 @@ horizon.inline_edit = {
             if (redir_url){
               location.href = redir_url;
             } else {
-              horizon.alert("error", gettext("Not authorized to do this operation."));
+              horizon.toast.add("error", gettext("Not authorized to do this operation."));
             }
           }
           else {
             if (!horizon.ajax.get_messages(jqXHR)) {
               // Generic error handler. Really generic.
-              horizon.alert("error", gettext("An error occurred. Please try again later."));
+              horizon.toast.add("error", gettext("An error occurred. Please try again later."));
             }
           }
         },
