@@ -15,7 +15,6 @@
 from __future__ import absolute_import
 
 from collections import OrderedDict
-from horizon.contrib import bootstrap_datepicker
 
 from django.conf import settings
 from django import template
@@ -24,8 +23,9 @@ from django.utils.encoding import force_text
 from django.utils import translation
 from django.utils.translation import ugettext_lazy as _
 
-from horizon.base import Horizon  # noqa
+from horizon.base import Horizon
 from horizon import conf
+from horizon.contrib import bootstrap_datepicker
 
 
 register = template.Library()
@@ -38,14 +38,12 @@ class MinifiedNode(Node):
     def render(self, context):
         return ' '.join(
             force_text(self.nodelist.render(context).strip()).split()
-        )
+        ).replace(' > ', '>').replace(' <', '<')
 
 
 @register.filter
 def has_permissions(user, component):
-    """Checks if the given user meets the permissions requirements for
-    the component.
-    """
+    """Checks if the given user meets the permissions requirements."""
     return user.has_perms(getattr(component, 'permissions', set()))
 
 
@@ -188,7 +186,9 @@ class JSTemplateNode(template.Node):
 
 @register.tag
 def jstemplate(parser, token):
-    """Replaces ``[[[`` and ``]]]`` with ``{{{`` and ``}}}``,
+    """Templatetag to handle any of the Mustache-based templates.
+
+    Replaces ``[[[`` and ``]]]`` with ``{{{`` and ``}}}``,
     ``[[`` and ``]]`` with ``{{`` and ``}}``  and
     ``[%`` and ``%]`` with ``{%`` and ``%}`` to avoid conflicts
     with Django's template engine when using any of the Mustache-based
@@ -211,11 +211,19 @@ def datepicker_locale():
     return locale_mapping.get(translation.get_language(), 'en')
 
 
+@register.assignment_tag
+def template_cache_age():
+    return getattr(settings, 'NG_TEMPLATE_CACHE_AGE', 0)
+
+
 @register.tag
 def minifyspace(parser, token):
-    """Removes whitespace including tab and newline characters. Do not use this
-    if you are using a <pre> tag
+    """Removes whitespace including tab and newline characters.
+
+    Do not use this if you are using a <pre> tag.
+
     Example usage::
+
         {% minifyspace %}
             <p>
                 <a title="foo"
@@ -224,8 +232,11 @@ def minifyspace(parser, token):
                 </a>
             </p>
         {% endminifyspace %}
+
     This example would return this HTML::
+
         <p><a title="foo" href="foo/">Foo</a></p>
+
     """
     nodelist = parser.parse(('endminifyspace',))
     parser.delete_first_token()
