@@ -26,18 +26,23 @@ from django.conf import settings
 from django.core.exceptions import SuspiciousFileOperation
 from django.template.engine import Engine
 from django.template.loaders.base import Loader as tLoaderCls
-from django.utils._os import safe_join  # noqa
+from django.utils._os import safe_join
 
 if django.VERSION >= (1, 9):
     from django.template.exceptions import TemplateDoesNotExist
 else:
-    from django.template.base import TemplateDoesNotExist  # noqa
+    from django.template.base import TemplateDoesNotExist
 
 
 # Local thread storage to retrieve the currently set theme
 _local = threading.local()
 
 
+# Get the themes from settings
+def get_selectable_themes():
+    return getattr(settings, 'SELECTABLE_THEMES', [])
+
+
 # Get the themes from settings
 def get_themes():
     return getattr(settings, 'AVAILABLE_THEMES',
@@ -87,9 +92,11 @@ def offline_context():
 # A piece of middleware that stores the theme cookie value into
 # local thread storage so the template loader can access it
 class ThemeMiddleware(object):
-    """The Theme Middleware component.  The custom template loaders
-       don't have access to the request object, so we need to store
-       the Cookie's theme value for use later in the Django chain.
+    """The Theme Middleware component.
+
+    The custom template loaders
+    don't have access to the request object, so we need to store
+    the Cookie's theme value for use later in the Django chain.
     """
 
     def process_request(self, request):
@@ -111,8 +118,10 @@ class ThemeMiddleware(object):
 
 
 class ThemeTemplateLoader(tLoaderCls):
-    """Themes can contain template overrides, so we need to check the
-       theme directory first, before loading any of the standard templates.
+    """Theme-aware template loader.
+
+    Themes can contain template overrides, so we need to check the
+    theme directory first, before loading any of the standard templates.
     """
     is_usable = True
 
@@ -133,7 +142,9 @@ class ThemeTemplateLoader(tLoaderCls):
                 pass
 
         try:
-            template_path = safe_join(
+            # To support themes residing outside of Django, use os.path.join to
+            # avoid throwing a SuspiciousFileOperation and immediately exiting.
+            template_path = os.path.join(
                 getattr(
                     settings,
                     'ROOT_PATH',
@@ -149,12 +160,9 @@ class ThemeTemplateLoader(tLoaderCls):
                     yield os.path.join(
                         this_theme[2], 'templates', template_name
                     )
-            elif template_name.find(template_path) != -1:
+            elif template_path in template_name:
                 yield template_name
 
-        except SuspiciousFileOperation:
-            # In case we are loading a theme outside of Django, pass along
-            pass
         except UnicodeDecodeError:
             # The template dir name wasn't valid UTF-8.
             raise
